==> copyq-2.4.2.tar.gz: CopyQ-2.4.2/src/gui/icons.h <==
/*
    Copyright (c) 2014, Lukas Holecek <hluk@email.cz>

    This file is part of CopyQ.

    CopyQ is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    CopyQ is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ICONS_H
#define ICONS_H

// http://fortawesome.github.com/Font-Awesome/design.html
enum IconId {
    IconFirst = 0xf000,
    IconSearch = 0xf002,
    IconThList = 0xf00b,
    IconRemove = 0xf00d,
    IconOff = 0xf011,
    IconCog = 0xf013,
    IconTrash = 0xf014,
    IconFileAlt = 0xf016,
    IconDownloadAlt = 0xf019,
    IconArrowCircleODown = 0xf01a,
    IconArrowCircleOUp = 0xf01b,
    IconInbox = 0xf01c,
    IconPlayCircle = 0xf01d,
    IconRepeat = 0xf01e,
    IconLock = 0xf023,
    IconListAlt = 0xf022,
    IconVolumeUp = 0xf028,
    IconQRCode = 0xf029,
    IconTag = 0xf02b,
    IconCamera = 0xf030,
    IconFont = 0xf031,
    IconPicture = 0xf03e,
    IconPencil = 0xf040,
    IconEdit = 0xf044,
    IconShare = 0xf045,
    IconRemoveSign = 0xf057,
    IconQuestionSign = 0xf059,
    IconInfoSign = 0xf05a,
    IconArrowLeft = 0xf060,
    IconArrowRight = 0xf061,
    IconArrowUp = 0xf062,
    IconArrowDown = 0xf063,
    IconPlus = 0xf067,
    IconMinus = 0xf068,
    IconAsterisk = 0xf069,
    IconExclamationSign = 0xf06a,
    IconEyeOpen = 0xf06e,
    IconEyeSlash = 0xf070,
    IconWarningSign = 0xf071,
    IconFolderOpen = 0xf07c,
    IconCogs = 0xf085,
    IconUploadAlt = 0xf093,
    IconUnlock = 0xf09c,
    IconHandUp = 0xf0a6,
    IconGlobe = 0xf0ac,
    IconWrench = 0xf0ad,
    IconLink = 0xf0c1,
    IconCopy = 0xf0c5,
    IconSave = 0xf0c7,
    IconListOl = 0xf0cb,
    IconSortDown = 0xf0dd,
    IconSortUp = 0xf0de,
    IconUndo = 0xf0e2,
    IconPaste = 0xf0ea,
    IconKeyboard = 0xf11c,
    IconUnlockAlt = 0xf13e,
    IconFile = 0xf15b,
    IconFileText = 0xf15c,
    IconSortByAlphabet = 0xf15d,
    IconSortByAlphabetAlt = 0xf15e,
    IconTerminal = 0xf120,
    IconEditSign = 0xf14b,
    IconArchive = 0xf187,
    IconLast = 0xf20c
};

#endif // ICONS_H

==> copyq_3.1.2.orig.tar.gz: CopyQ-3.1.2/src/gui/icons.h <==
/*
    Copyright (c) 2017, Lukas Holecek <hluk@email.cz>

    This file is part of CopyQ.

    CopyQ is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    CopyQ is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ICONS_H
#define ICONS_H

// http://fortawesome.github.com/Font-Awesome/design.html
enum IconId {
    IconFirst = 0xf000,
    IconSearch = 0xf002,
    IconUser = 0xf007,
    IconThList = 0xf00b,
    IconCheck = 0xf00c,
    IconRemove = 0xf00d,
    IconOff = 0xf011,
    IconCog = 0xf013,
    IconTrash = 0xf014,
    IconHome = 0xf015,
    IconFileAlt = 0xf016,
    IconClockO = 0xf017,
    IconDownloadAlt = 0xf019,
    IconArrowCircleODown = 0xf01a,
    IconArrowCircleOUp = 0xf01b,
    IconInbox = 0xf01c,
    IconPlayCircle = 0xf01d,
    IconRepeat = 0xf01e,
    IconLock = 0xf023,
    IconListAlt = 0xf022,
    IconVolumeUp = 0xf028,
    IconQRCode = 0xf029,
    IconTag = 0xf02b,
    IconBook = 0xf02d,
    IconCamera = 0xf030,
    IconFont = 0xf031,
    IconBold = 0xf032,
    IconItalic = 0xf033,
    IconPicture = 0xf03e,
    IconPencil = 0xf040,
    IconEdit = 0xf044,
    IconShare = 0xf045,
    IconRemoveSign = 0xf057,
    IconQuestionSign = 0xf059,
    IconInfoSign = 0xf05a,
    IconBan = 0xf05e,
    IconArrowLeft = 0xf060,
    IconArrowRight = 0xf061,
    IconArrowUp = 0xf062,
    IconArrowDown = 0xf063,
    IconPlus = 0xf067,
    IconMinus = 0xf068,
    IconAsterisk = 0xf069,
    IconExclamationSign = 0xf06a,
    IconGift = 0xf06b,
    IconEyeOpen = 0xf06e,
    IconEyeSlash = 0xf070,
    IconWarningSign = 0xf071,
    IconFolderOpen = 0xf07c,
    IconCogs = 0xf085,
    IconThumbTack  = 0xf08d,
    IconUploadAlt = 0xf093,
    IconSquareO = 0xf096,
    IconUnlock = 0xf09c,
    IconHandUp = 0xf0a6,
    IconGlobe = 0xf0ac,
    IconWrench = 0xf0ad,
    IconLink = 0xf0c1,
    IconCopy = 0xf0c5,
    IconSave = 0xf0c7,
    IconSquare = 0xf0c8,
    IconBars = 0xf0c9,
    IconListOl = 0xf0cb,
    IconStrikethrough = 0xf0cc,
    IconUnderline = 0xf0cd,
    IconColumns = 0xf0db,
    IconSortDown = 0xf0dd,
    IconSortUp = 0xf0de,
    IconEnvelope = 0xf0e0,
    IconUndo = 0xf0e2,
    IconBolt = 0xf0e7,
    IconPaste = 0xf0ea,
    IconAngleDoubleUp = 0xf102,
    IconAngleDoubleDown = 0xf103,
    IconAngleUp = 0xf106,
    IconAngleDown = 0xf107,
    IconKeyboard = 0xf11c,
    IconUnlockAlt = 0xf13e,
    IconFile = 0xf15b,
    IconFileText = 0xf15c,
    IconSortByAlphabet = 0xf15d,
    IconSortByAlphabetAlt = 0xf15e,
    IconTerminal = 0xf120,
    IconEraser = 0xf12d,
    IconEditSign = 0xf14b,
    IconArchive = 0xf187
};

#endif // ICONS_H
